import {ContentEditableDirective} from './content-editable.directive';
import {Component} from "@angular/core";
import {ComponentFixture, TestBed} from "@angular/core/testing";
import {By} from "@angular/platform-browser";
import {FormControl, FormGroup, ReactiveFormsModule} from "@angular/forms";

// We will use a fake component to test this directive
@Component({
  template: `
    <form [formGroup]="formGroup" id="form">
      <div id="contentBlock" contenteditable="true" propValueAccessor="innerHTML" formControlName="notes">Starting
        Text
      </div>
    </form>`
})
class TestComponent {
  formGroup = new FormGroup({
    notes: new FormControl('Starting Text')
  });
}

describe('ContentEditableDirective', () => {

  let component: TestComponent;
  let fixture: ComponentFixture<TestComponent>;
  let div: HTMLDivElement;
  let form: HTMLFormElement;

  beforeEach(() => {
    fixture = TestBed.configureTestingModule({
      imports: [ReactiveFormsModule],
      declarations: [TestComponent, ContentEditableDirective]
    }).createComponent(TestComponent);

    component = fixture.componentInstance;

    fixture.detectChanges(); //ngOnInit

    const des = fixture.debugElement.query(By.directive(ContentEditableDirective));
    const directive = des.injector.get(ContentEditableDirective) as ContentEditableDirective;
    div = des.nativeElement as HTMLDivElement;
    form = fixture.debugElement.query(By.css('#form')).nativeElement;
  });

  it('should create an instance', () => {
    expect(component).toBeTruthy();
  });

  it('should be editable and update form', () => {
    expect(div.innerHTML).toEqual('Starting Text', 'default innerHTML is Starting Text');
    div.innerHTML = 'New Text';
    div.dispatchEvent(new Event('input'));
    fixture.detectChanges();
    expect(component.formGroup.get('notes').value).toEqual('New Text', 'form control updated from div');

  });

});
